@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-import logging
 import importlib.metadata
-
+import logging
 
 __version__ = importlib.metadata.version("simmate")
 
 # Some of these utilities use the __version__ above, so this import must come after
-from simmate.utilities import get_doc_from_readme, check_if_using_latest_version
+from simmate.utilities import check_if_using_latest_version, get_doc_from_readme
 
 __doc__ = get_doc_from_readme(__file__)
 
@@ -15,7 +14,7 @@ __doc__ = get_doc_from_readme(__file__)
 # Configure our logger to output timestamps and "SIMMATE" with logs
 # Also changes the logging level to info
 logging.basicConfig(
-    format="[SIMMATE-%(levelname)-s %(asctime)-s] %(message)s",
+    format="[SIMMATE-%(levelname)-s | %(asctime)-s] %(message)s",
     level=logging.INFO,
     datefmt="%Y-%m-%d %H:%M:%S",
 )
@@ -26,4 +25,4 @@ logging.basicConfig(
 try:
     check_if_using_latest_version()
 except:
-    logging.warn("Unable to check if using the latest Simmate version.")
+    logging.warning("Unable to check if using the latest Simmate version.")
