@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
 
-import os
-from pathlib import Path
-import time
 import datetime
-import subprocess
 import logging
+import os
+import subprocess
+import time
+from pathlib import Path
 
 import numpy
 from pymatgen.io.vasp.outputs import Outcar
 
-from simmate.workflow_engine import ErrorHandler
 from simmate.calculators.vasp.error_handlers import Unconverged
+from simmate.workflow_engine import ErrorHandler
 
 
 class Walltime(ErrorHandler):
@@ -143,7 +143,9 @@ class Walltime(ErrorHandler):
             # handlers updating them)
             filename = directory / "simmate_metadata.yaml"
             if not filename.exists():
-                logging.warn("Unable to detect the time remaining. Ignoring Timeout.")
+                logging.warning(
+                    "Unable to detect the time remaining. Ignoring Timeout."
+                )
                 return
                 # !!! What if I looked at the creation time of the current directory?
 
@@ -164,7 +166,7 @@ class Walltime(ErrorHandler):
             ).stdout.strip()
             # parse the output into a time
             if output == "INVALID":
-                logging.warn(
+                logging.warning(
                     "SLURM node improperly configured. " "Cannot detect TimeLeft"
                 )
                 return
@@ -177,7 +179,7 @@ class Walltime(ErrorHandler):
                 try:
                     output = [int(i) for i in output.replace("-", ":").split(":")]
                 except:
-                    logging.warn(
+                    logging.warning(
                         "Failed to parse SLURM output. Please report this to the"
                         f"Simmate team. Output was {output}"
                     )
