@@ -7,10 +7,11 @@ This defines the base "simmate" command that all other commands stem from.
 import click
 
 from simmate.command_line.database import database
-from simmate.command_line.workflows import workflows
-from simmate.command_line.workflow_engine import workflow_engine
 from simmate.command_line.run_server import run_server
 from simmate.command_line.start_project import start_project
+from simmate.command_line.utilities import utilities
+from simmate.command_line.workflow_engine import workflow_engine
+from simmate.command_line.workflows import workflows
 
 
 @click.group()
@@ -37,6 +38,7 @@ simmate.add_command(workflows)
 simmate.add_command(workflow_engine)
 simmate.add_command(run_server)
 simmate.add_command(start_project)
+simmate.add_command(utilities)
 
 # explicitly list functions so that pdoc doesn't skip them
 __all__ = ["simmate"]
