@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# from prefect.backend.flow_run import FlowRunView
+import platform
 
 from simmate.database.base_data_types import DatabaseTable, table_column
 
@@ -20,12 +20,32 @@ class Calculation(DatabaseTable):
 
     base_info = [
         "directory",
-        "prefect_flow_run_id",
+        "run_id",
         "created_at",
         "updated_at",
         "corrections",
     ]
 
+    workflow_name = table_column.CharField(
+        max_length=75,
+        blank=True,
+        null=True,
+    )
+    """
+    The full name of the workflow used, such as "relaxation.vasp.matproj".
+    """
+
+    location = table_column.CharField(
+        max_length=75,
+        blank=True,
+        null=True,
+    )
+    """
+    This is the location/computer that the workflow was ran on. It will be something
+    like... "DESKTOP-PVN50G5" or "Warwulf". This value is set automatically
+    using `platform.node()`
+    """
+
     directory = table_column.CharField(
         max_length=250,
         blank=True,
@@ -35,9 +55,8 @@ class Calculation(DatabaseTable):
     This is the folder that the workflow was ran in. It will be something
     like... "/path/to/simmate-task-abc123"
     """
-    # TODO: maybe add host computer name too? (via platform.node())
 
-    prefect_flow_run_id = table_column.CharField(
+    run_id = table_column.CharField(
         max_length=50,
         blank=True,
         null=True,
@@ -67,12 +86,12 @@ class Calculation(DatabaseTable):
         doesn't check to confirm it's been registered. To actually confirm that,
         use the `flow_run_view` attribute instead.
         """
-        return f"https://cloud.prefect.io/simmate/flow-run/{self.prefect_flow_run_id}"
+        return f"https://cloud.prefect.io/simmate/flow-run/{self.run_id}"
 
     @property
     def flow_run_view(self):  # -> FlowRunView
         """
-        Checks if the prefect_flow_run_id was registered with Prefect Cloud, and
+        Checks if the run_id was registered with Prefect Cloud, and
         if so, returns a
         [FlowRunView](https://docs.prefect.io/orchestration/flow-runs/inspection.html)
         that hold metadata such as the status. This metadata includes...
@@ -95,16 +114,12 @@ class Calculation(DatabaseTable):
         If Prefect Cloud is not configured or if the calculation was ran
         locally, the None is returned.
         """
-        raise NotImplementedError("Migrating to Prefect 2.0")
-        try:
-            return FlowRunView.from_flow_run_id(self.prefect_flow_run_id)
-        except:  # may fail if this is a local run or prefect api key not configured
-            return None
+        raise NotImplementedError("This feature has no been migrated to Prefect 2.0")
 
     @property
     def prefect_flow_run_name(self) -> str:
         """
-        Gives the user-friendly name of this run if the prefect_flow_run_id
+        Gives the user-friendly name of this run if the run_id
         was registered with Prefect Cloud. (an example name is "friendly-bumblebee").
         """
         flowrunview = self.flow_run_view
@@ -113,14 +128,19 @@ class Calculation(DatabaseTable):
     @property
     def prefect_state(self) -> str:
         """
-        Gives the current state of this run if the prefect_flow_run_id
+        Gives the current state of this run if the run_id
         was registered with Prefect Cloud. (ex: "Scheduled" or "Successful")
         """
         flowrunview = self.flow_run_view
         return flowrunview.state.__class__.__name__ if flowrunview else None
 
     @classmethod
-    def from_prefect_id(cls, prefect_flow_run_id: str, **kwargs):
+    def from_run_context(
+        cls,
+        run_id: str = None,
+        workflow_name: str = None,
+        **kwargs,
+    ):
         """
         Given a prefect id, this method will do one of the following...
 
@@ -130,20 +150,38 @@ class Calculation(DatabaseTable):
         It will then return the corresponding Calculation instance.
         """
 
+        if not run_id or not workflow_name:
+            # Grab the database_table that we want to save the results in
+            from prefect.context import FlowRunContext
+
+            run_context = FlowRunContext.get()
+            if run_context:
+                workflow = run_context.flow.simmate_workflow
+                workflow_name = workflow.name_full
+                run_id = str(run_context.flow_run.id)
+                assert workflow.database_table == cls
+            else:
+                raise Exception(
+                    "No Prefect FlowRunContext was detected, so you must provide "
+                    "flow_id and workflow_name to the from_run_context method."
+                )
+
         # Depending on how a workflow was submitted, there may be a calculation
         # extry existing already -- which we need to grab and then update. If it's
         # not there, we create a new one!
 
         # check if the calculation already exists in our database, and if so,
         # grab it and return it.
-        if cls.objects.filter(prefect_flow_run_id=prefect_flow_run_id).exists():
-            return cls.objects.get(prefect_flow_run_id=prefect_flow_run_id)
+        if cls.objects.filter(run_id=run_id).exists():
+            return cls.objects.get(run_id=run_id)
         # Otherwise we need to create a new one and return that.
 
         # To handle the initialization of other Simmate mix-ins, we pass all
         # information to the from_toolkit method rather than directly to cls.
         calculation = cls.from_toolkit(
-            prefect_flow_run_id=prefect_flow_run_id,
+            run_id=run_id,
+            location=platform.node(),
+            workflow_name=workflow_name,
             **kwargs,
         )
         calculation.save()
