@@ -6,17 +6,16 @@ This module is experimental and subject to change.
 
 from pathlib import Path
 
-from simmate.database.base_data_types import (
-    table_column,
-    Structure,
-    Forces,
-    Thermodynamics,
-    Calculation,
-)
-
-from typing import List
 from pymatgen.io.vasp.outputs import Vasprun
 
+from simmate.database.base_data_types import (
+    Calculation,
+    Forces,
+    Structure,
+    Thermodynamics,
+    table_column,
+)
+
 
 class DynamicsRun(Structure, Calculation):
     """
@@ -56,7 +55,7 @@ class DynamicsRun(Structure, Calculation):
     def update_from_vasp_run(
         self,
         vasprun: Vasprun,
-        corrections: List,
+        corrections: list[tuple[str]],
         directory: Path,
     ):
         """
