@@ -4,9 +4,9 @@ from simmate.utilities import get_doc_from_readme
 
 __doc__ = get_doc_from_readme(__file__)
 
-from .aflow import AflowStructure, AflowPrototype
+from .aflow import AflowPrototype, AflowStructure
 from .cod import CodStructure
 from .jarvis import JarvisStructure
 from .materials_project import MatprojStructure
 from .oqmd import OqmdStructure
-from .utilities import load_remote_archives, load_default_sqlite3_build
+from .utilities import load_default_sqlite3_build, load_remote_archives
