@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
 import pytest
-from pytest_django.asserts import assertTemplateUsed
 from django.urls import reverse
+from pytest_django.asserts import assertTemplateUsed
 
 from simmate.workflow_engine import Workflow
 from simmate.workflows.utilities import (
-    get_workflow_types,
     get_list_of_all_workflows,
     get_workflow,
+    get_workflow_types,
 )
 
 ALL_WORKFLOWS = get_list_of_all_workflows()
@@ -42,6 +42,8 @@ def test_workflow_detail_view(client, workflow_name):
     if workflow_name in [
         "restart.simmate.automatic",
         "electronic-structure.vasp.matproj-full",
+        "structure-prediction.python.fixed-composition",
+        "structure-prediction.python.new-individual",
     ]:
         return
 
@@ -133,5 +135,7 @@ def test_workflow_submit_view(client, sample_structures, mocker):
         # parameters not deserialized yet so these will still be present
         command="",
         directory="",
+        source=None,
+        run_id="",
         is_restart=False,
     )
