@@ -171,28 +171,18 @@ into one class, we make things much easier for users and creating new Tasks.
 
 """
 
+import logging
 import os
 import platform
-import time
 import signal
 import subprocess
-from typing import List, Tuple
+import time
 from pathlib import Path
-import logging
 
 import pandas
 
-from simmate.workflow_engine import Workflow, ErrorHandler
-from simmate.utilities import get_directory, make_archive, make_error_archive
-
-# cleanup_on_fail=False, # TODO I should add a Prefect state_handler that can
-# reset the working directory between task retries -- in some cases we may
-# want to delete the entire directory.
-
-# OPTIMIZE: I think this class would greatly benefit from asyncio so that we
-# know exactly when a shelltask completes, rather than looping and checking every
-# set timestep.
-# https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.create_subprocess_exec
+from simmate.utilities import get_directory, make_error_archive
+from simmate.workflow_engine import ErrorHandler, Workflow
 
 
 class S3Workflow(Workflow):
@@ -216,7 +206,7 @@ class S3Workflow(Workflow):
     and before `execute` is called. By default, no input files are required.
     """
 
-    error_handlers: List[ErrorHandler] = []
+    error_handlers: list[ErrorHandler] = []
     """
     A list of ErrorHandler objects to use in order of priority (that is, highest
     priority is first). If one handler is triggered, the correction will be 
@@ -256,13 +246,21 @@ class S3Workflow(Workflow):
     we run monitoring functions every 5 minutes (10x30=300s=5min).
     """
 
+    # cleanup_on_fail=False, # TODO I should add a Prefect state_handler that can
+    # reset the working directory between task retries -- in some cases we may
+    # want to delete the entire directory.
+
+    # OPTIMIZE: I think this class would greatly benefit from asyncio so that we
+    # know exactly when a shelltask completes, rather than looping and checking every
+    # set timestep.
+    # https://docs.python.org/3/library/asyncio-subprocess.html#asyncio.create_subprocess_exec
+
     @classmethod
     def run_config(
         cls,
         directory: Path = None,
         command: str = None,
         is_restart: bool = False,
-        compress_output: bool = False,
         **kwargs,
     ):
         """
@@ -292,11 +290,6 @@ class S3Workflow(Workflow):
             called instead of the setup method. Extra checks will be made to
             see if the calculation completed already too.
 
-        - `compress_output`:
-            Whether to compress the directory to a zip file at the end of the
-            task run. After compression, it will also delete the directory.
-            The default is False.
-
          - `**kwargs`:
              Any extra keywords that should be passed to the setup() method.
 
@@ -360,11 +353,6 @@ class S3Workflow(Workflow):
         # out from the calculation and is thus our "result".
         result = cls.workup(directory=directory)
 
-        # if requested, compresses the directory to a zip file and then removes
-        # the directory.
-        if compress_output:
-            make_archive(directory)
-
         # Return our final information as a dictionary
         result = {
             "result": result,
@@ -463,7 +451,7 @@ class S3Workflow(Workflow):
         return True  # indicates all files are present
 
     @classmethod
-    def execute(cls, directory: Path, command: str) -> List[Tuple[str]]:
+    def execute(cls, directory: Path, command: str) -> list[tuple[str]]:
         """
         This calls the command within the target directory and handles all error
         handling as well as monitoring of the job.
@@ -629,12 +617,27 @@ class S3Workflow(Workflow):
             # exception here but instead let the monitor handle that
             # error in the code below.
             if process.returncode != 0 and not has_error:
+
                 # convert the error from bytes to a string
                 errors = errors.decode("utf-8")
-                # and report the error to the user
-                raise NonZeroExitError(
-                    f"The command ({command}) failed. The error output was...\n {errors}"
-                )
+                # and report the error to the user. Mac/Linux label this as exit
+                # code 127, whereas windows doesn't so the message needs to be
+                # read.
+                if process.returncode == 127 or (
+                    platform.system() == "Windows"
+                    and "is not recognized as an internal or external command"
+                ):
+                    raise CommandNotFoundError(
+                        f"The command ({command}) failed becauase it could not be found. "
+                        "This typically means that either (a) you have not installed "
+                        "the program required for this command or (b) you forgot to "
+                        "call 'module load ...' before trying to start the program. "
+                        f"The full error output was:\n\n {errors}"
+                    )
+                else:
+                    raise NonZeroExitError(
+                        f"The command ({command}) failed. The error output was...\n {errors}"
+                    )
 
             # Check for errors again, because a non-monitor may be higher
             # priority than the monitor triggered above (if there was one).
@@ -813,3 +816,7 @@ class MaxCorrectionsError(Exception):
 
 class NonZeroExitError(Exception):
     pass
+
+
+class CommandNotFoundError(NonZeroExitError):
+    pass
