@@ -8,7 +8,9 @@ Workflows for calculating the energy of material
 # if "simmate.calculators.vasp" in installed_apps:
 from simmate.calculators.vasp.workflows.static_energy.all import (
     StaticEnergy__Vasp__Matproj,
+    StaticEnergy__Vasp__MatprojHse,
+    StaticEnergy__Vasp__MatprojScan,
     StaticEnergy__Vasp__Mit,
+    StaticEnergy__Vasp__MvlNebEndpoint,
     StaticEnergy__Vasp__Quality04,
-    StaticEnergy__Vasp__NebEndpoint,
 )
